@@ -498,7 +498,8 @@ iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
 iptables --policy OUTPUT ACCEPT 
 echo "off-D"
-iptables -D INPUT -j RB_RELATED_AND_ESTABLISHED
+iptables -D INPUT -j RB_I_RELATED_AND_ESTABLISHED
+iptables -D OUTPUT -j RB_O_RELATED_AND_ESTABLISHED
 iptables -D OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH
 iptables -D DOCKER-USER -j RB_DOCKER_VPN_KILL_SWITCH
 ip6tables --policy INPUT ACCEPT
@@ -516,15 +517,18 @@ iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
 iptables --policy OUTPUT ACCEPT 
 echo "flush-D"
-iptables -D INPUT -j RB_RELATED_AND_ESTABLISHED
+iptables -D INPUT -j RB_I_RELATED_AND_ESTABLISHED
+iptables -D OUTPUT -j RB_O_RELATED_AND_ESTABLISHED
 iptables -D OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH
 iptables -D DOCKER-USER -j RB_DOCKER_VPN_KILL_SWITCH
 echo "flush-F"
-iptables --flush RB_RELATED_AND_ESTABLISHED
+iptables --flush RB_I_RELATED_AND_ESTABLISHED
+iptables --flush RB_O_RELATED_AND_ESTABLISHED
 iptables --flush RB_OUTPUT_VPN_KILL_SWITCH
 iptables --flush RB_DOCKER_VPN_KILL_SWITCH
 echo "flush-D"
-iptables --delete-chain RB_RELATED_AND_ESTABLISHED
+iptables --delete-chain RB_I_RELATED_AND_ESTABLISHED
+iptables --delete-chain RB_O_RELATED_AND_ESTABLISHED
 iptables --delete-chain RB_OUTPUT_VPN_KILL_SWITCH
 iptables --delete-chain RB_DOCKER_VPN_KILL_SWITCH
 ip6tables --policy INPUT ACCEPT
@@ -541,10 +545,16 @@ sysctl_file_enable_ipv6
 #Block all traffic as default.
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
-iptables --policy OUTPUT ACCEPT
-create_filter_chain 'RB_RELATED_AND_ESTABLISHED'
-create_filter_rule 'iptables -A RB_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
-create_filter_rule 'iptables -I INPUT -j RB_RELATED_AND_ESTABLISHED'
+iptables --policy OUTPUT DROP
+create_filter_rule 'iptables -A INPUT -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A FORWARD -m state --state INVALID -j DROP'
+create_filter_rule 'iptables -A OUTPUT -m state --state INVALID -j DROP'
+create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -I INPUT -j RB_I_RELATED_AND_ESTABLISHED'
+create_filter_chain 'RB_O_RELATED_AND_ESTABLISHED'
+create_filter_rule 'iptables -A RB_O_RELATED_AND_ESTABLISHED -m conntrack --ctstate NEW,RELATED,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -I OUTPUT -j RB_O_RELATED_AND_ESTABLISHED'
 ip6tables --policy INPUT DROP
 ip6tables --policy FORWARD DROP
 ip6tables --policy OUTPUT DROP
@@ -560,9 +570,9 @@ sysctl_file_disable_ipv6
 iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
 iptables --policy OUTPUT DROP
-create_filter_chain 'RB_RELATED_AND_ESTABLISHED'
-create_filter_rule 'iptables -A RB_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
-create_filter_rule 'iptables -I INPUT  -j RB_RELATED_AND_ESTABLISHED'
+create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
+create_filter_rule 'iptables -I INPUT  -j RB_I_RELATED_AND_ESTABLISHED'
 #let's create a chain named RB_OUTPUT_VPN_KILL_SWITCH to hold our VPN rules
 create_filter_chain 'RB_OUTPUT_VPN_KILL_SWITCH'
 create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -p udp -m udp --dport 1194 -j ACCEPT'
@@ -594,10 +604,10 @@ iptables --policy INPUT DROP
 iptables --policy FORWARD DROP
 iptables --policy OUTPUT DROP
 #Create a custom chain to contain rules to allow related and established traffic.
-create_filter_chain 'RB_RELATED_AND_ESTABLISHED'
-create_filter_rule 'iptables -A RB_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
-#Divert input traffic to the RB_RELATED_AND_ESTABLISHED chain.
-create_filter_rule 'iptables -I INPUT -j RB_RELATED_AND_ESTABLISHED'
+create_filter_chain 'RB_I_RELATED_AND_ESTABLISHED'
+create_filter_rule 'iptables -A RB_I_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
+#Divert input traffic to the RB_I_RELATED_AND_ESTABLISHED chain.
+create_filter_rule 'iptables -I INPUT -j RB_I_RELATED_AND_ESTABLISHED'
 #Let's allow the loopback device.
 #let's create a chain named RB_OUTPUT_VPN_KILL_SWITCH to hold our VPN rules
 create_filter_chain 'RB_OUTPUT_VPN_KILL_SWITCH'
